@@ -54,12 +54,9 @@ public:
 
     void drawGrid(QPainter *painter, const QRectF &rect, QColor grid) const override;
 
-    void drawTileLayer(QPainter *painter, const TileLayer *layer,
-                       const QRectF &exposed = QRectF()) const override;
-
-    void drawTileLayer(const TileLayer *layer,
-                       const RenderTileCallback &renderTile,
-                       const QRectF &exposed = QRectF()) const override;
+    using MapRenderer::drawTileLayer;
+    void drawTileLayer(const RenderTileCallback &renderTile,
+                       const QRectF &exposed) const override;
 
     void drawTileSelection(QPainter *painter,
                            const QRegion &region,
